{
  description = "Super Nintendo Interface";

  # Nixpkgs / NixOS version to use.
  inputs.nixpkgs.url = "nixpkgs/release-23.11";
  inputs.flake-utils.url = "github:numtide/flake-utils";

  outputs = {
    self,
    nixpkgs,
    flake-utils,
  }: let
    # to work with older version of flakes
    lastModifiedDate = self.lastModifiedDate or self.lastModified or "19700101";

    version = "0.0.95";
  in
    flake-utils.lib.eachDefaultSystem (system: let
      pkgs = nixpkgs.legacyPackages.${system};
    in {
      # Provide some binary packages for selected system types.
      packages = rec {
        default = sni;

        sni = pkgs.buildGoModule {
          pname = "sni";
          inherit version;

          src = pkgs.fetchFromGitHub {
            owner = "alttpo";
            repo = "sni";
            rev = "v${version}";
            hash = "sha256-lk4RIeObwdyTJzPcDYhSxkT9VG8Y6FWnsHQcjGJdfwI=";
          };

          buildInputs = with pkgs; [
            gtk3.dev
            libayatana-appindicator.dev
          ];
          nativeBuildInputs = [
            pkgs.pkg-config
          ];

          subPackages = "./cmd/sni";

          # This hash locks the dependencies of this package. It is
          # necessary because of how Go requires network access to resolve
          # VCS.  See https://www.tweag.io/blog/2021-03-04-gomod2nix/ for
          # details. Normally one can build with a fake sha256 and rely on native Go
          # mechanisms to tell you what the hash should be or determine what
          # it should be "out-of-band" with other tooling (eg. gomod2nix).
          # To begin with it is recommended to set this, but one must
          # remeber to bump this hash when your dependencies change.
          vendorHash = "sha256-hvIfGu7SQ+OV5iPYlvuOIpE9OqMLRCuUpl5YCpsmBWI=";

          meta = with pkgs.lib; {
            description = "An interface that allows multiple concurrent applications to access various kinds of Super Nintendo devices connected to the computer";
            homepage = "https://github.com/alttpo/sni";
            license = licenses.mit;
            maintainers = with maintainers; [island_usurper];
          };
        };

        apps = rec {
          sni = {
            type = "app";
            program = "${self.packages.${system}.sni}/bin/sni";
          };
          default = sni;
        };

        devShells = {
          default = pkgs.mkShell {
            buildInputs = with pkgs; [
              go
              gtk3.dev
              libayatana-appindicator.dev
              pkg-config
            ];
          };
        };
      };
    });
}
